OidcWebCore class

Core web package for oidc

Constructors

OidcWebCore()
Core web package for oidc
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAuthorizationResponse(OidcProviderMetadata metadata, OidcAuthorizeRequest request, OidcPlatformSpecificOptions_Web options, Map<String, dynamic> preparationResult) Future<OidcAuthorizeResponse?>
Returns the authorization response. may throw an OidcException.
getEndSessionResponse(OidcProviderMetadata metadata, OidcEndSessionRequest request, OidcPlatformSpecificOptions_Web options, Map<String, dynamic> preparationResult) Future<OidcEndSessionResponse?>
Returns the end session response for an RP initiated logout request. may throw an OidcException.
listenToFrontChannelLogoutRequests(Uri listenOn, OidcFrontChannelRequestListeningOptions_Web options) Stream<OidcFrontChannelLogoutIncomingRequest>
Listens to incoming front channel logout requests. returns an empty stream on non-supported platforms.
monitorSessionStatus({required Uri checkSessionIframe, required OidcMonitorSessionStatusRequest request}) Stream<OidcMonitorSessionResult>
starts monitoring the session status.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
prepareForRedirectFlow(OidcPlatformSpecificOptions_Web options) Map<String, dynamic>
prepares the window for the given navigation mode
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited